@@ -27,6 +27,7 @@ from .invite_links import InviteLinks
 from .messages import Messages
 from .password import Password
 from .premium import Premium
+from .pyrodev import Pyrodev
 from .users import Users
 from .stories import Stories
 from .utilities import Utilities
@@ -43,6 +44,7 @@ class Methods(
     Users,
     Stories,
     Messages,
+    Pyrodev,
     Decorators,
     Utilities,
     InviteLinks,
